# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Any, Dict, Union, Iterable, cast
from datetime import datetime
from typing_extensions import Literal, overload

import httpx

from ..types import (
    order_create_params,
    order_update_params,
    order_update_status_params,
    order_upload_results_params,
    order_retrieve_results_params,
    order_send_for_employee_params,
    order_schedule_appointment_params,
)
from .._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from .._utils import required_args, maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.order_create_response import OrderCreateResponse
from ..types.order_update_response import OrderUpdateResponse
from ..types.order_retrieve_response import OrderRetrieveResponse
from ..types.order_update_status_response import OrderUpdateStatusResponse
from ..types.order_upload_results_response import OrderUploadResultsResponse
from ..types.order_retrieve_results_response import OrderRetrieveResultsResponse
from ..types.order_send_for_employee_response import OrderSendForEmployeeResponse
from ..types.order_schedule_appointment_response import OrderScheduleAppointmentResponse

__all__ = ["OrdersResource", "AsyncOrdersResource"]


class OrdersResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> OrdersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return OrdersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> OrdersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return OrdersResourceWithStreamingResponse(self)

    @overload
    def create(
        self,
        *,
        payment_method: Literal["self-pay", "employer-sponsored"],
        person: order_create_params.Variant0Person,
        provider_id: str,
        services: Iterable[order_create_params.Variant0Service],
        _id: str | Omit = omit,
        brand_id: str | Omit = omit,
        due_date: Union[str, datetime] | Omit = omit,
        due_dates: SequenceNotStr[Union[str, datetime]] | Omit = omit,
        employee_id: str | Omit = omit,
        employee_ids: SequenceNotStr[str] | Omit = omit,
        employer_id: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        priority: Literal["normal", "high"] | Omit = omit,
        provider_created: bool | Omit = omit,
        providers_ids: Iterable[order_create_params.Variant0ProvidersID] | Omit = omit,
        quantities: Dict[str, int] | Omit = omit,
        re_captcha_token: str | Omit = omit,
        services_ids: SequenceNotStr[str] | Omit = omit,
        token_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderCreateResponse:
        """
        Create orders for consumers (self-pay or employer-sponsored), employers, or bulk
        orders. Consolidates functionality from legacy Order.createOrder and
        Order.SendOrder methods.

        Args:
          metadata: Optional arbitrary metadata (<=10KB when JSON stringified)

          priority: Order priority level

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        employee_id: str,
        employer_id: str,
        services: Iterable[order_create_params.Variant1Service],
        _id: str | Omit = omit,
        brand_id: str | Omit = omit,
        due_date: Union[str, datetime] | Omit = omit,
        due_dates: SequenceNotStr[Union[str, datetime]] | Omit = omit,
        employee_ids: SequenceNotStr[str] | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        payment_method: Literal["self-pay", "employer-sponsored"] | Omit = omit,
        person: order_create_params.Variant1Person | Omit = omit,
        priority: Literal["normal", "high"] | Omit = omit,
        provider_created: bool | Omit = omit,
        provider_id: str | Omit = omit,
        providers_ids: Iterable[order_create_params.Variant1ProvidersID] | Omit = omit,
        quantities: Dict[str, int] | Omit = omit,
        re_captcha_token: str | Omit = omit,
        services_ids: SequenceNotStr[str] | Omit = omit,
        token_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderCreateResponse:
        """
        Create orders for consumers (self-pay or employer-sponsored), employers, or bulk
        orders. Consolidates functionality from legacy Order.createOrder and
        Order.SendOrder methods.

        Args:
          metadata: Optional arbitrary metadata (<=10KB when JSON stringified)

          priority: Order priority level

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        employee_id: str,
        employer_id: str,
        providers_ids: Iterable[order_create_params.Variant2ProvidersID],
        services_ids: SequenceNotStr[str],
        _id: str | Omit = omit,
        brand_id: str | Omit = omit,
        due_date: Union[str, datetime] | Omit = omit,
        due_dates: SequenceNotStr[Union[str, datetime]] | Omit = omit,
        employee_ids: SequenceNotStr[str] | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        payment_method: Literal["self-pay", "employer-sponsored"] | Omit = omit,
        person: order_create_params.Variant2Person | Omit = omit,
        priority: Literal["normal", "high"] | Omit = omit,
        provider_created: bool | Omit = omit,
        provider_id: str | Omit = omit,
        quantities: Dict[str, int] | Omit = omit,
        re_captcha_token: str | Omit = omit,
        services: Iterable[order_create_params.Variant2Service] | Omit = omit,
        token_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderCreateResponse:
        """
        Create orders for consumers (self-pay or employer-sponsored), employers, or bulk
        orders. Consolidates functionality from legacy Order.createOrder and
        Order.SendOrder methods.

        Args:
          metadata: Optional arbitrary metadata (<=10KB when JSON stringified)

          priority: Order priority level

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        employee_ids: SequenceNotStr[str],
        employer_id: str,
        providers_ids: Iterable[order_create_params.Variant3ProvidersID],
        services_ids: SequenceNotStr[str],
        _id: str | Omit = omit,
        brand_id: str | Omit = omit,
        due_date: Union[str, datetime] | Omit = omit,
        due_dates: SequenceNotStr[Union[str, datetime]] | Omit = omit,
        employee_id: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        payment_method: Literal["self-pay", "employer-sponsored"] | Omit = omit,
        person: order_create_params.Variant3Person | Omit = omit,
        priority: Literal["normal", "high"] | Omit = omit,
        provider_created: bool | Omit = omit,
        provider_id: str | Omit = omit,
        quantities: Dict[str, int] | Omit = omit,
        re_captcha_token: str | Omit = omit,
        services: Iterable[order_create_params.Variant3Service] | Omit = omit,
        token_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderCreateResponse:
        """
        Create orders for consumers (self-pay or employer-sponsored), employers, or bulk
        orders. Consolidates functionality from legacy Order.createOrder and
        Order.SendOrder methods.

        Args:
          metadata: Optional arbitrary metadata (<=10KB when JSON stringified)

          priority: Order priority level

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(
        ["payment_method", "person", "provider_id", "services"],
        ["employee_id", "employer_id", "services"],
        ["employee_id", "employer_id", "providers_ids", "services_ids"],
        ["employee_ids", "employer_id", "providers_ids", "services_ids"],
    )
    def create(
        self,
        *,
        payment_method: Literal["self-pay", "employer-sponsored"] | Omit = omit,
        person: order_create_params.Variant0Person
        | order_create_params.Variant1Person
        | order_create_params.Variant2Person
        | order_create_params.Variant3Person
        | Omit = omit,
        provider_id: str | Omit = omit,
        services: Iterable[order_create_params.Variant0Service]
        | Iterable[order_create_params.Variant1Service]
        | Iterable[order_create_params.Variant2Service]
        | Iterable[order_create_params.Variant3Service]
        | Omit = omit,
        _id: str | Omit = omit,
        brand_id: str | Omit = omit,
        due_date: Union[str, datetime] | Omit = omit,
        due_dates: SequenceNotStr[Union[str, datetime]] | Omit = omit,
        employee_id: str | Omit = omit,
        employee_ids: SequenceNotStr[str] | Omit = omit,
        employer_id: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        priority: Literal["normal", "high"] | Omit = omit,
        provider_created: bool | Omit = omit,
        providers_ids: Iterable[order_create_params.Variant0ProvidersID]
        | Iterable[order_create_params.Variant1ProvidersID]
        | Iterable[order_create_params.Variant2ProvidersID]
        | Iterable[order_create_params.Variant3ProvidersID]
        | Omit = omit,
        quantities: Dict[str, int] | Omit = omit,
        re_captcha_token: str | Omit = omit,
        services_ids: SequenceNotStr[str] | Omit = omit,
        token_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderCreateResponse:
        return cast(
            OrderCreateResponse,
            self._post(
                "/v1/orders",
                body=maybe_transform(
                    {
                        "payment_method": payment_method,
                        "person": person,
                        "provider_id": provider_id,
                        "services": services,
                        "_id": _id,
                        "brand_id": brand_id,
                        "due_date": due_date,
                        "due_dates": due_dates,
                        "employee_id": employee_id,
                        "employee_ids": employee_ids,
                        "employer_id": employer_id,
                        "metadata": metadata,
                        "priority": priority,
                        "provider_created": provider_created,
                        "providers_ids": providers_ids,
                        "quantities": quantities,
                        "re_captcha_token": re_captcha_token,
                        "services_ids": services_ids,
                        "token_id": token_id,
                    },
                    order_create_params.OrderCreateParams,
                ),
                options=make_request_options(
                    extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
                ),
                cast_to=cast(
                    Any, OrderCreateResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )

    def retrieve(
        self,
        order_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderRetrieveResponse:
        """
        Retrieve details for a specific order

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not order_id:
            raise ValueError(f"Expected a non-empty value for `order_id` but received {order_id!r}")
        return self._get(
            f"/v1/orders/{order_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrderRetrieveResponse,
        )

    def update(
        self,
        order_id: str,
        *,
        metadata: Dict[str, object] | Omit = omit,
        services: Iterable[order_update_params.Service] | Omit = omit,
        status: Literal[
            "order_sent", "order_accepted", "order_refused", "employee_confirmed", "order_fulfilled", "order_complete"
        ]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderUpdateResponse:
        """Update order details and associated order items.

        Allows updating order status,
        metadata, and modifying order item services.

        Args:
          metadata: Arbitrary metadata to update on the order (non-indexed passthrough, <=10KB when
              JSON stringified)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not order_id:
            raise ValueError(f"Expected a non-empty value for `order_id` but received {order_id!r}")
        return self._post(
            f"/v1/orders/{order_id}",
            body=maybe_transform(
                {
                    "metadata": metadata,
                    "services": services,
                    "status": status,
                },
                order_update_params.OrderUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrderUpdateResponse,
        )

    def retrieve_results(
        self,
        order_id: str,
        *,
        page: int | Omit = omit,
        page_size: int | Omit = omit,
        service_id: str | Omit = omit,
        since: Union[str, datetime] | Omit = omit,
        status: str | Omit = omit,
        until: Union[str, datetime] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderRetrieveResultsResponse:
        """Retrieve results for an order.

        Supports filtering by serviceId, status, date
        window, and pagination.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not order_id:
            raise ValueError(f"Expected a non-empty value for `order_id` but received {order_id!r}")
        return self._get(
            f"/v1/orders/{order_id}/results",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page": page,
                        "page_size": page_size,
                        "service_id": service_id,
                        "since": since,
                        "status": status,
                        "until": until,
                    },
                    order_retrieve_results_params.OrderRetrieveResultsParams,
                ),
            ),
            cast_to=OrderRetrieveResultsResponse,
        )

    def schedule_appointment(
        self,
        order_id: str,
        *,
        appointment: order_schedule_appointment_params.Appointment,
        order_access_code: str | Omit = omit,
        provider_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderScheduleAppointmentResponse:
        """Schedule an appointment or walk-in for an existing order.

        Sends HL7 SIU^S12
        message for appointment booking.

        Args:
          order_access_code: Order access code for authorization

          provider_id: Provider ID for authorization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not order_id:
            raise ValueError(f"Expected a non-empty value for `order_id` but received {order_id!r}")
        return self._post(
            f"/v1/orders/{order_id}/schedule-appointment",
            body=maybe_transform(
                {
                    "appointment": appointment,
                    "order_access_code": order_access_code,
                    "provider_id": provider_id,
                },
                order_schedule_appointment_params.OrderScheduleAppointmentParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrderScheduleAppointmentResponse,
        )

    def send_for_employee(
        self,
        *,
        employee_id: str,
        employer_id: str,
        providers_ids: Iterable[order_send_for_employee_params.ProvidersID],
        services_ids: SequenceNotStr[str],
        login_token: str,
        user_id: str,
        brand_id: str | Omit = omit,
        due_date: str | Omit = omit,
        due_dates: SequenceNotStr[str] | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        priority: Literal["normal", "high"] | Omit = omit,
        provider_created: bool | Omit = omit,
        provider_id: str | Omit = omit,
        quantities: Dict[str, int] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderSendForEmployeeResponse:
        """Send an order for a specific employee.

        Requires API key, login token, and user
        ID. This endpoint specifically handles employer-to-employee order sending.

        Args:
          employee_id: Employee ID to send order to

          employer_id: Employer ID sending the order

          providers_ids: Array mapping each service (by index) to a provider; serviceId optional

          services_ids: Array of service IDs to include in the order

          brand_id: Brand ID for branded orders

          due_date: Due date for the order (date or date-time ISO string)

          due_dates: Array of due dates per service

          metadata: Optional arbitrary metadata to store on the order (non-indexed passthrough,
              <=10KB when JSON stringified)

          priority: Order priority level

          provider_created: Whether this order is being created by a provider (affects permission checking)

          provider_id: Single provider ID (shortcut when all services map to one provider)

          quantities: Service ID to quantity mapping

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"login-token": login_token, "user-id": user_id, **(extra_headers or {})}
        return cast(
            OrderSendForEmployeeResponse,
            self._post(
                "/v1/orders/send",
                body=maybe_transform(
                    {
                        "employee_id": employee_id,
                        "employer_id": employer_id,
                        "providers_ids": providers_ids,
                        "services_ids": services_ids,
                        "brand_id": brand_id,
                        "due_date": due_date,
                        "due_dates": due_dates,
                        "metadata": metadata,
                        "priority": priority,
                        "provider_created": provider_created,
                        "provider_id": provider_id,
                        "quantities": quantities,
                    },
                    order_send_for_employee_params.OrderSendForEmployeeParams,
                ),
                options=make_request_options(
                    extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
                ),
                cast_to=cast(
                    Any, OrderSendForEmployeeResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )

    def update_status(
        self,
        order_id: str,
        *,
        status: Literal[
            "order_sent", "order_accepted", "order_refused", "employee_confirmed", "order_fulfilled", "order_complete"
        ],
        message: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderUpdateStatusResponse:
        """
        Update the status of an existing order

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not order_id:
            raise ValueError(f"Expected a non-empty value for `order_id` but received {order_id!r}")
        return self._put(
            f"/v1/orders/{order_id}/status",
            body=maybe_transform(
                {
                    "status": status,
                    "message": message,
                },
                order_update_status_params.OrderUpdateStatusParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrderUpdateStatusResponse,
        )

    def upload_results(
        self,
        order_id: str,
        *,
        captcha_token: str,
        order_access_code: str,
        service_id: str,
        dob: str | Omit = omit,
        file_ids: SequenceNotStr[str] | Omit = omit,
        files: Iterable[order_upload_results_params.File] | Omit = omit,
        last_name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderUploadResultsResponse:
        """Upload test results for a specific order item.

        Supports both existing fileIds
        and base64 encoded files. Requires order access code and employee verification.

        Args:
          dob: Date of birth in YYYY-MM-DD format

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not order_id:
            raise ValueError(f"Expected a non-empty value for `order_id` but received {order_id!r}")
        return self._post(
            f"/v1/orders/{order_id}/upload-results",
            body=maybe_transform(
                {
                    "captcha_token": captcha_token,
                    "order_access_code": order_access_code,
                    "service_id": service_id,
                    "dob": dob,
                    "file_ids": file_ids,
                    "files": files,
                    "last_name": last_name,
                },
                order_upload_results_params.OrderUploadResultsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrderUploadResultsResponse,
        )


class AsyncOrdersResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncOrdersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncOrdersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOrdersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return AsyncOrdersResourceWithStreamingResponse(self)

    @overload
    async def create(
        self,
        *,
        payment_method: Literal["self-pay", "employer-sponsored"],
        person: order_create_params.Variant0Person,
        provider_id: str,
        services: Iterable[order_create_params.Variant0Service],
        _id: str | Omit = omit,
        brand_id: str | Omit = omit,
        due_date: Union[str, datetime] | Omit = omit,
        due_dates: SequenceNotStr[Union[str, datetime]] | Omit = omit,
        employee_id: str | Omit = omit,
        employee_ids: SequenceNotStr[str] | Omit = omit,
        employer_id: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        priority: Literal["normal", "high"] | Omit = omit,
        provider_created: bool | Omit = omit,
        providers_ids: Iterable[order_create_params.Variant0ProvidersID] | Omit = omit,
        quantities: Dict[str, int] | Omit = omit,
        re_captcha_token: str | Omit = omit,
        services_ids: SequenceNotStr[str] | Omit = omit,
        token_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderCreateResponse:
        """
        Create orders for consumers (self-pay or employer-sponsored), employers, or bulk
        orders. Consolidates functionality from legacy Order.createOrder and
        Order.SendOrder methods.

        Args:
          metadata: Optional arbitrary metadata (<=10KB when JSON stringified)

          priority: Order priority level

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        employee_id: str,
        employer_id: str,
        services: Iterable[order_create_params.Variant1Service],
        _id: str | Omit = omit,
        brand_id: str | Omit = omit,
        due_date: Union[str, datetime] | Omit = omit,
        due_dates: SequenceNotStr[Union[str, datetime]] | Omit = omit,
        employee_ids: SequenceNotStr[str] | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        payment_method: Literal["self-pay", "employer-sponsored"] | Omit = omit,
        person: order_create_params.Variant1Person | Omit = omit,
        priority: Literal["normal", "high"] | Omit = omit,
        provider_created: bool | Omit = omit,
        provider_id: str | Omit = omit,
        providers_ids: Iterable[order_create_params.Variant1ProvidersID] | Omit = omit,
        quantities: Dict[str, int] | Omit = omit,
        re_captcha_token: str | Omit = omit,
        services_ids: SequenceNotStr[str] | Omit = omit,
        token_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderCreateResponse:
        """
        Create orders for consumers (self-pay or employer-sponsored), employers, or bulk
        orders. Consolidates functionality from legacy Order.createOrder and
        Order.SendOrder methods.

        Args:
          metadata: Optional arbitrary metadata (<=10KB when JSON stringified)

          priority: Order priority level

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        employee_id: str,
        employer_id: str,
        providers_ids: Iterable[order_create_params.Variant2ProvidersID],
        services_ids: SequenceNotStr[str],
        _id: str | Omit = omit,
        brand_id: str | Omit = omit,
        due_date: Union[str, datetime] | Omit = omit,
        due_dates: SequenceNotStr[Union[str, datetime]] | Omit = omit,
        employee_ids: SequenceNotStr[str] | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        payment_method: Literal["self-pay", "employer-sponsored"] | Omit = omit,
        person: order_create_params.Variant2Person | Omit = omit,
        priority: Literal["normal", "high"] | Omit = omit,
        provider_created: bool | Omit = omit,
        provider_id: str | Omit = omit,
        quantities: Dict[str, int] | Omit = omit,
        re_captcha_token: str | Omit = omit,
        services: Iterable[order_create_params.Variant2Service] | Omit = omit,
        token_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderCreateResponse:
        """
        Create orders for consumers (self-pay or employer-sponsored), employers, or bulk
        orders. Consolidates functionality from legacy Order.createOrder and
        Order.SendOrder methods.

        Args:
          metadata: Optional arbitrary metadata (<=10KB when JSON stringified)

          priority: Order priority level

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        employee_ids: SequenceNotStr[str],
        employer_id: str,
        providers_ids: Iterable[order_create_params.Variant3ProvidersID],
        services_ids: SequenceNotStr[str],
        _id: str | Omit = omit,
        brand_id: str | Omit = omit,
        due_date: Union[str, datetime] | Omit = omit,
        due_dates: SequenceNotStr[Union[str, datetime]] | Omit = omit,
        employee_id: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        payment_method: Literal["self-pay", "employer-sponsored"] | Omit = omit,
        person: order_create_params.Variant3Person | Omit = omit,
        priority: Literal["normal", "high"] | Omit = omit,
        provider_created: bool | Omit = omit,
        provider_id: str | Omit = omit,
        quantities: Dict[str, int] | Omit = omit,
        re_captcha_token: str | Omit = omit,
        services: Iterable[order_create_params.Variant3Service] | Omit = omit,
        token_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderCreateResponse:
        """
        Create orders for consumers (self-pay or employer-sponsored), employers, or bulk
        orders. Consolidates functionality from legacy Order.createOrder and
        Order.SendOrder methods.

        Args:
          metadata: Optional arbitrary metadata (<=10KB when JSON stringified)

          priority: Order priority level

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(
        ["payment_method", "person", "provider_id", "services"],
        ["employee_id", "employer_id", "services"],
        ["employee_id", "employer_id", "providers_ids", "services_ids"],
        ["employee_ids", "employer_id", "providers_ids", "services_ids"],
    )
    async def create(
        self,
        *,
        payment_method: Literal["self-pay", "employer-sponsored"] | Omit = omit,
        person: order_create_params.Variant0Person
        | order_create_params.Variant1Person
        | order_create_params.Variant2Person
        | order_create_params.Variant3Person
        | Omit = omit,
        provider_id: str | Omit = omit,
        services: Iterable[order_create_params.Variant0Service]
        | Iterable[order_create_params.Variant1Service]
        | Iterable[order_create_params.Variant2Service]
        | Iterable[order_create_params.Variant3Service]
        | Omit = omit,
        _id: str | Omit = omit,
        brand_id: str | Omit = omit,
        due_date: Union[str, datetime] | Omit = omit,
        due_dates: SequenceNotStr[Union[str, datetime]] | Omit = omit,
        employee_id: str | Omit = omit,
        employee_ids: SequenceNotStr[str] | Omit = omit,
        employer_id: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        priority: Literal["normal", "high"] | Omit = omit,
        provider_created: bool | Omit = omit,
        providers_ids: Iterable[order_create_params.Variant0ProvidersID]
        | Iterable[order_create_params.Variant1ProvidersID]
        | Iterable[order_create_params.Variant2ProvidersID]
        | Iterable[order_create_params.Variant3ProvidersID]
        | Omit = omit,
        quantities: Dict[str, int] | Omit = omit,
        re_captcha_token: str | Omit = omit,
        services_ids: SequenceNotStr[str] | Omit = omit,
        token_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderCreateResponse:
        return cast(
            OrderCreateResponse,
            await self._post(
                "/v1/orders",
                body=await async_maybe_transform(
                    {
                        "payment_method": payment_method,
                        "person": person,
                        "provider_id": provider_id,
                        "services": services,
                        "_id": _id,
                        "brand_id": brand_id,
                        "due_date": due_date,
                        "due_dates": due_dates,
                        "employee_id": employee_id,
                        "employee_ids": employee_ids,
                        "employer_id": employer_id,
                        "metadata": metadata,
                        "priority": priority,
                        "provider_created": provider_created,
                        "providers_ids": providers_ids,
                        "quantities": quantities,
                        "re_captcha_token": re_captcha_token,
                        "services_ids": services_ids,
                        "token_id": token_id,
                    },
                    order_create_params.OrderCreateParams,
                ),
                options=make_request_options(
                    extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
                ),
                cast_to=cast(
                    Any, OrderCreateResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )

    async def retrieve(
        self,
        order_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderRetrieveResponse:
        """
        Retrieve details for a specific order

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not order_id:
            raise ValueError(f"Expected a non-empty value for `order_id` but received {order_id!r}")
        return await self._get(
            f"/v1/orders/{order_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrderRetrieveResponse,
        )

    async def update(
        self,
        order_id: str,
        *,
        metadata: Dict[str, object] | Omit = omit,
        services: Iterable[order_update_params.Service] | Omit = omit,
        status: Literal[
            "order_sent", "order_accepted", "order_refused", "employee_confirmed", "order_fulfilled", "order_complete"
        ]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderUpdateResponse:
        """Update order details and associated order items.

        Allows updating order status,
        metadata, and modifying order item services.

        Args:
          metadata: Arbitrary metadata to update on the order (non-indexed passthrough, <=10KB when
              JSON stringified)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not order_id:
            raise ValueError(f"Expected a non-empty value for `order_id` but received {order_id!r}")
        return await self._post(
            f"/v1/orders/{order_id}",
            body=await async_maybe_transform(
                {
                    "metadata": metadata,
                    "services": services,
                    "status": status,
                },
                order_update_params.OrderUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrderUpdateResponse,
        )

    async def retrieve_results(
        self,
        order_id: str,
        *,
        page: int | Omit = omit,
        page_size: int | Omit = omit,
        service_id: str | Omit = omit,
        since: Union[str, datetime] | Omit = omit,
        status: str | Omit = omit,
        until: Union[str, datetime] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderRetrieveResultsResponse:
        """Retrieve results for an order.

        Supports filtering by serviceId, status, date
        window, and pagination.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not order_id:
            raise ValueError(f"Expected a non-empty value for `order_id` but received {order_id!r}")
        return await self._get(
            f"/v1/orders/{order_id}/results",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "page": page,
                        "page_size": page_size,
                        "service_id": service_id,
                        "since": since,
                        "status": status,
                        "until": until,
                    },
                    order_retrieve_results_params.OrderRetrieveResultsParams,
                ),
            ),
            cast_to=OrderRetrieveResultsResponse,
        )

    async def schedule_appointment(
        self,
        order_id: str,
        *,
        appointment: order_schedule_appointment_params.Appointment,
        order_access_code: str | Omit = omit,
        provider_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderScheduleAppointmentResponse:
        """Schedule an appointment or walk-in for an existing order.

        Sends HL7 SIU^S12
        message for appointment booking.

        Args:
          order_access_code: Order access code for authorization

          provider_id: Provider ID for authorization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not order_id:
            raise ValueError(f"Expected a non-empty value for `order_id` but received {order_id!r}")
        return await self._post(
            f"/v1/orders/{order_id}/schedule-appointment",
            body=await async_maybe_transform(
                {
                    "appointment": appointment,
                    "order_access_code": order_access_code,
                    "provider_id": provider_id,
                },
                order_schedule_appointment_params.OrderScheduleAppointmentParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrderScheduleAppointmentResponse,
        )

    async def send_for_employee(
        self,
        *,
        employee_id: str,
        employer_id: str,
        providers_ids: Iterable[order_send_for_employee_params.ProvidersID],
        services_ids: SequenceNotStr[str],
        login_token: str,
        user_id: str,
        brand_id: str | Omit = omit,
        due_date: str | Omit = omit,
        due_dates: SequenceNotStr[str] | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        priority: Literal["normal", "high"] | Omit = omit,
        provider_created: bool | Omit = omit,
        provider_id: str | Omit = omit,
        quantities: Dict[str, int] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderSendForEmployeeResponse:
        """Send an order for a specific employee.

        Requires API key, login token, and user
        ID. This endpoint specifically handles employer-to-employee order sending.

        Args:
          employee_id: Employee ID to send order to

          employer_id: Employer ID sending the order

          providers_ids: Array mapping each service (by index) to a provider; serviceId optional

          services_ids: Array of service IDs to include in the order

          brand_id: Brand ID for branded orders

          due_date: Due date for the order (date or date-time ISO string)

          due_dates: Array of due dates per service

          metadata: Optional arbitrary metadata to store on the order (non-indexed passthrough,
              <=10KB when JSON stringified)

          priority: Order priority level

          provider_created: Whether this order is being created by a provider (affects permission checking)

          provider_id: Single provider ID (shortcut when all services map to one provider)

          quantities: Service ID to quantity mapping

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"login-token": login_token, "user-id": user_id, **(extra_headers or {})}
        return cast(
            OrderSendForEmployeeResponse,
            await self._post(
                "/v1/orders/send",
                body=await async_maybe_transform(
                    {
                        "employee_id": employee_id,
                        "employer_id": employer_id,
                        "providers_ids": providers_ids,
                        "services_ids": services_ids,
                        "brand_id": brand_id,
                        "due_date": due_date,
                        "due_dates": due_dates,
                        "metadata": metadata,
                        "priority": priority,
                        "provider_created": provider_created,
                        "provider_id": provider_id,
                        "quantities": quantities,
                    },
                    order_send_for_employee_params.OrderSendForEmployeeParams,
                ),
                options=make_request_options(
                    extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
                ),
                cast_to=cast(
                    Any, OrderSendForEmployeeResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )

    async def update_status(
        self,
        order_id: str,
        *,
        status: Literal[
            "order_sent", "order_accepted", "order_refused", "employee_confirmed", "order_fulfilled", "order_complete"
        ],
        message: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderUpdateStatusResponse:
        """
        Update the status of an existing order

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not order_id:
            raise ValueError(f"Expected a non-empty value for `order_id` but received {order_id!r}")
        return await self._put(
            f"/v1/orders/{order_id}/status",
            body=await async_maybe_transform(
                {
                    "status": status,
                    "message": message,
                },
                order_update_status_params.OrderUpdateStatusParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrderUpdateStatusResponse,
        )

    async def upload_results(
        self,
        order_id: str,
        *,
        captcha_token: str,
        order_access_code: str,
        service_id: str,
        dob: str | Omit = omit,
        file_ids: SequenceNotStr[str] | Omit = omit,
        files: Iterable[order_upload_results_params.File] | Omit = omit,
        last_name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderUploadResultsResponse:
        """Upload test results for a specific order item.

        Supports both existing fileIds
        and base64 encoded files. Requires order access code and employee verification.

        Args:
          dob: Date of birth in YYYY-MM-DD format

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not order_id:
            raise ValueError(f"Expected a non-empty value for `order_id` but received {order_id!r}")
        return await self._post(
            f"/v1/orders/{order_id}/upload-results",
            body=await async_maybe_transform(
                {
                    "captcha_token": captcha_token,
                    "order_access_code": order_access_code,
                    "service_id": service_id,
                    "dob": dob,
                    "file_ids": file_ids,
                    "files": files,
                    "last_name": last_name,
                },
                order_upload_results_params.OrderUploadResultsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrderUploadResultsResponse,
        )


class OrdersResourceWithRawResponse:
    def __init__(self, orders: OrdersResource) -> None:
        self._orders = orders

        self.create = to_raw_response_wrapper(
            orders.create,
        )
        self.retrieve = to_raw_response_wrapper(
            orders.retrieve,
        )
        self.update = to_raw_response_wrapper(
            orders.update,
        )
        self.retrieve_results = to_raw_response_wrapper(
            orders.retrieve_results,
        )
        self.schedule_appointment = to_raw_response_wrapper(
            orders.schedule_appointment,
        )
        self.send_for_employee = to_raw_response_wrapper(
            orders.send_for_employee,
        )
        self.update_status = to_raw_response_wrapper(
            orders.update_status,
        )
        self.upload_results = to_raw_response_wrapper(
            orders.upload_results,
        )


class AsyncOrdersResourceWithRawResponse:
    def __init__(self, orders: AsyncOrdersResource) -> None:
        self._orders = orders

        self.create = async_to_raw_response_wrapper(
            orders.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            orders.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            orders.update,
        )
        self.retrieve_results = async_to_raw_response_wrapper(
            orders.retrieve_results,
        )
        self.schedule_appointment = async_to_raw_response_wrapper(
            orders.schedule_appointment,
        )
        self.send_for_employee = async_to_raw_response_wrapper(
            orders.send_for_employee,
        )
        self.update_status = async_to_raw_response_wrapper(
            orders.update_status,
        )
        self.upload_results = async_to_raw_response_wrapper(
            orders.upload_results,
        )


class OrdersResourceWithStreamingResponse:
    def __init__(self, orders: OrdersResource) -> None:
        self._orders = orders

        self.create = to_streamed_response_wrapper(
            orders.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            orders.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            orders.update,
        )
        self.retrieve_results = to_streamed_response_wrapper(
            orders.retrieve_results,
        )
        self.schedule_appointment = to_streamed_response_wrapper(
            orders.schedule_appointment,
        )
        self.send_for_employee = to_streamed_response_wrapper(
            orders.send_for_employee,
        )
        self.update_status = to_streamed_response_wrapper(
            orders.update_status,
        )
        self.upload_results = to_streamed_response_wrapper(
            orders.upload_results,
        )


class AsyncOrdersResourceWithStreamingResponse:
    def __init__(self, orders: AsyncOrdersResource) -> None:
        self._orders = orders

        self.create = async_to_streamed_response_wrapper(
            orders.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            orders.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            orders.update,
        )
        self.retrieve_results = async_to_streamed_response_wrapper(
            orders.retrieve_results,
        )
        self.schedule_appointment = async_to_streamed_response_wrapper(
            orders.schedule_appointment,
        )
        self.send_for_employee = async_to_streamed_response_wrapper(
            orders.send_for_employee,
        )
        self.update_status = async_to_streamed_response_wrapper(
            orders.update_status,
        )
        self.upload_results = async_to_streamed_response_wrapper(
            orders.upload_results,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from .._utils import PropertyInfo

__all__ = ["OrderScheduleAppointmentParams", "Appointment", "AppointmentUnionMember0", "AppointmentUnionMember1"]


class OrderScheduleAppointmentParams(TypedDict, total=False):
    appointment: Required[Appointment]

    order_access_code: Annotated[str, PropertyInfo(alias="orderAccessCode")]
    """Order access code for authorization"""

    provider_id: Annotated[str, PropertyInfo(alias="providerId")]
    """Provider ID for authorization"""


class AppointmentUnionMember0(TypedDict, total=False):
    date: Required[str]
    """Required for appointment type"""

    date_time: Required[Annotated[Union[str, datetime], PropertyInfo(alias="dateTime", format="iso8601")]]
    """Required for appointment type"""

    time: Required[str]
    """Required for appointment type"""

    notes: str
    """Optional for walkin type"""

    type: Literal["appointment"]


class AppointmentUnionMember1(TypedDict, total=False):
    date: str
    """Required for appointment type"""

    date_time: Annotated[Union[str, datetime], PropertyInfo(alias="dateTime", format="iso8601")]
    """Required for appointment type"""

    notes: str
    """Optional for walkin type"""

    time: str
    """Required for appointment type"""

    type: Literal["walkin"]


Appointment: TypeAlias = Union[AppointmentUnionMember0, AppointmentUnionMember1]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["OrderRetrieveResponse"]


class OrderRetrieveResponse(BaseModel):
    order_id: Optional[str] = FieldInfo(alias="orderId", default=None)

    order_number: Optional[str] = FieldInfo(alias="orderNumber", default=None)

    status: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["Hl7SendResultsParams", "File"]


class Hl7SendResultsParams(TypedDict, total=False):
    employee_id: Required[Annotated[str, PropertyInfo(alias="employeeId")]]
    """Employee ID to send results for"""

    file: Required[File]
    """File containing the results"""


class File(TypedDict, total=False):
    """File containing the results"""

    base64: Required[str]
    """Base64 encoded file content"""

    name: Required[str]
    """File name"""

    type: Required[str]
    """MIME type of the file"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["OrderRetrieveResultsParams"]


class OrderRetrieveResultsParams(TypedDict, total=False):
    page: int

    page_size: Annotated[int, PropertyInfo(alias="pageSize")]

    service_id: Annotated[str, PropertyInfo(alias="serviceId")]

    since: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]

    status: str

    until: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["EmployeeLinkUserResponse"]


class EmployeeLinkUserResponse(BaseModel):
    """Employee linked successfully"""

    link_id: str = FieldInfo(alias="linkId")
    """ID of the created link"""

    message: str

    success: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = [
    "ServiceBundleListResponse",
    "ServiceBundleListResponseItem",
    "ServiceBundleListResponseItemIntegrationData",
    "ServiceBundleListResponseItemIntegrationDataEnterpriseHealth",
]


class ServiceBundleListResponseItemIntegrationDataEnterpriseHealth(BaseModel):
    add_on_services: Optional[bool] = FieldInfo(alias="addOnServices", default=None)


class ServiceBundleListResponseItemIntegrationData(BaseModel):
    enterprise_health: Optional[ServiceBundleListResponseItemIntegrationDataEnterpriseHealth] = FieldInfo(
        alias="enterprise-health", default=None
    )


class ServiceBundleListResponseItem(BaseModel):
    api_id: str = FieldInfo(alias="_id")

    bundle_name: str = FieldInfo(alias="bundleName")

    employer_id: str = FieldInfo(alias="employerId")

    service_ids: List[str] = FieldInfo(alias="serviceIds")

    created_at: Optional[str] = FieldInfo(alias="createdAt", default=None)

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)

    externally_managed: Optional[bool] = FieldInfo(alias="externallyManaged", default=None)
    """Indicates if this bundle originated from a third-party integration.

    Externally managed bundles cannot be edited or deleted in BlueHive.
    """

    integration: Optional[str] = None
    """
    Name of the third-party integration that manages this bundle (e.g., "Enterprise
    Health"). Null if bundle was created in BlueHive.
    """

    integration_data: Optional[ServiceBundleListResponseItemIntegrationData] = FieldInfo(
        alias="integrationData", default=None
    )

    limit: Optional[float] = None

    occurrence: Optional[str] = None

    recurring: Optional[bool] = None

    roles: Optional[List[str]] = None

    start_date: Optional[str] = FieldInfo(alias="startDate", default=None)

    updated_at: Optional[str] = FieldInfo(alias="updatedAt", default=None)

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)


ServiceBundleListResponse: TypeAlias = List[ServiceBundleListResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import fax_send_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.fax_send_response import FaxSendResponse
from ..types.fax_list_providers_response import FaxListProvidersResponse
from ..types.fax_retrieve_status_response import FaxRetrieveStatusResponse

__all__ = ["FaxResource", "AsyncFaxResource"]


class FaxResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> FaxResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return FaxResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> FaxResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return FaxResourceWithStreamingResponse(self)

    def list_providers(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> FaxListProvidersResponse:
        """Get a list of available fax providers and their configuration status."""
        return self._get(
            "/v1/fax/providers",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FaxListProvidersResponse,
        )

    def retrieve_status(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> FaxRetrieveStatusResponse:
        """
        Retrieve the current status and details of a fax by its ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/v1/fax/status/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FaxRetrieveStatusResponse,
        )

    def send(
        self,
        *,
        document: fax_send_params.Document,
        to: str,
        from_: str | Omit = omit,
        provider: str | Omit = omit,
        subject: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> FaxSendResponse:
        """
        Send a fax document to a specified number using the configured fax provider.

        Args:
          to: Recipient fax number (E.164 format preferred)

          from_: Sender fax number (optional, uses default if not provided)

          provider: Optional provider override (uses default if not specified)

          subject: Subject line for the fax

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/fax/send",
            body=maybe_transform(
                {
                    "document": document,
                    "to": to,
                    "from_": from_,
                    "provider": provider,
                    "subject": subject,
                },
                fax_send_params.FaxSendParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FaxSendResponse,
        )


class AsyncFaxResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncFaxResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncFaxResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncFaxResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return AsyncFaxResourceWithStreamingResponse(self)

    async def list_providers(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> FaxListProvidersResponse:
        """Get a list of available fax providers and their configuration status."""
        return await self._get(
            "/v1/fax/providers",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FaxListProvidersResponse,
        )

    async def retrieve_status(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> FaxRetrieveStatusResponse:
        """
        Retrieve the current status and details of a fax by its ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/v1/fax/status/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FaxRetrieveStatusResponse,
        )

    async def send(
        self,
        *,
        document: fax_send_params.Document,
        to: str,
        from_: str | Omit = omit,
        provider: str | Omit = omit,
        subject: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> FaxSendResponse:
        """
        Send a fax document to a specified number using the configured fax provider.

        Args:
          to: Recipient fax number (E.164 format preferred)

          from_: Sender fax number (optional, uses default if not provided)

          provider: Optional provider override (uses default if not specified)

          subject: Subject line for the fax

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/fax/send",
            body=await async_maybe_transform(
                {
                    "document": document,
                    "to": to,
                    "from_": from_,
                    "provider": provider,
                    "subject": subject,
                },
                fax_send_params.FaxSendParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FaxSendResponse,
        )


class FaxResourceWithRawResponse:
    def __init__(self, fax: FaxResource) -> None:
        self._fax = fax

        self.list_providers = to_raw_response_wrapper(
            fax.list_providers,
        )
        self.retrieve_status = to_raw_response_wrapper(
            fax.retrieve_status,
        )
        self.send = to_raw_response_wrapper(
            fax.send,
        )


class AsyncFaxResourceWithRawResponse:
    def __init__(self, fax: AsyncFaxResource) -> None:
        self._fax = fax

        self.list_providers = async_to_raw_response_wrapper(
            fax.list_providers,
        )
        self.retrieve_status = async_to_raw_response_wrapper(
            fax.retrieve_status,
        )
        self.send = async_to_raw_response_wrapper(
            fax.send,
        )


class FaxResourceWithStreamingResponse:
    def __init__(self, fax: FaxResource) -> None:
        self._fax = fax

        self.list_providers = to_streamed_response_wrapper(
            fax.list_providers,
        )
        self.retrieve_status = to_streamed_response_wrapper(
            fax.retrieve_status,
        )
        self.send = to_streamed_response_wrapper(
            fax.send,
        )


class AsyncFaxResourceWithStreamingResponse:
    def __init__(self, fax: AsyncFaxResource) -> None:
        self._fax = fax

        self.list_providers = async_to_streamed_response_wrapper(
            fax.list_providers,
        )
        self.retrieve_status = async_to_streamed_response_wrapper(
            fax.retrieve_status,
        )
        self.send = async_to_streamed_response_wrapper(
            fax.send,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["EmployeeUnlinkUserParams"]


class EmployeeUnlinkUserParams(TypedDict, total=False):
    employee_id: Required[Annotated[str, PropertyInfo(alias="employeeId")]]
    """ID of the employee to unlink"""

    user_id: Required[Annotated[str, PropertyInfo(alias="userId")]]
    """ID of the user to unlink from"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable

import httpx

from ...types import employer_create_params
from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from .service_bundles import (
    ServiceBundlesResource,
    AsyncServiceBundlesResource,
    ServiceBundlesResourceWithRawResponse,
    AsyncServiceBundlesResourceWithRawResponse,
    ServiceBundlesResourceWithStreamingResponse,
    AsyncServiceBundlesResourceWithStreamingResponse,
)
from ...types.employer_list_response import EmployerListResponse
from ...types.employer_create_response import EmployerCreateResponse
from ...types.employer_retrieve_response import EmployerRetrieveResponse

__all__ = ["EmployersResource", "AsyncEmployersResource"]


class EmployersResource(SyncAPIResource):
    @cached_property
    def service_bundles(self) -> ServiceBundlesResource:
        return ServiceBundlesResource(self._client)

    @cached_property
    def with_raw_response(self) -> EmployersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return EmployersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EmployersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return EmployersResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        address: employer_create_params.Address,
        email: str,
        name: str,
        phones: Iterable[employer_create_params.Phone],
        billing_address: Dict[str, object] | Omit = omit,
        checkr: employer_create_params.Checkr | Omit = omit,
        demo: bool | Omit = omit,
        employee_consent: bool | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        onsite_clinic: bool | Omit = omit,
        website: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployerCreateResponse:
        """
        Create Employer

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/employers",
            body=maybe_transform(
                {
                    "address": address,
                    "email": email,
                    "name": name,
                    "phones": phones,
                    "billing_address": billing_address,
                    "checkr": checkr,
                    "demo": demo,
                    "employee_consent": employee_consent,
                    "metadata": metadata,
                    "onsite_clinic": onsite_clinic,
                    "website": website,
                },
                employer_create_params.EmployerCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployerCreateResponse,
        )

    def retrieve(
        self,
        employer_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployerRetrieveResponse:
        """
        Get Employer

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employer_id:
            raise ValueError(f"Expected a non-empty value for `employer_id` but received {employer_id!r}")
        return self._get(
            f"/v1/employers/{employer_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployerRetrieveResponse,
        )

    def list(
        self,
        *,
        login_token: str,
        user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployerListResponse:
        """
        Get Employers for Current User

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"login-token": login_token, "user-id": user_id, **(extra_headers or {})}
        return self._get(
            "/v1/employers/list",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployerListResponse,
        )


class AsyncEmployersResource(AsyncAPIResource):
    @cached_property
    def service_bundles(self) -> AsyncServiceBundlesResource:
        return AsyncServiceBundlesResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncEmployersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncEmployersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEmployersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return AsyncEmployersResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        address: employer_create_params.Address,
        email: str,
        name: str,
        phones: Iterable[employer_create_params.Phone],
        billing_address: Dict[str, object] | Omit = omit,
        checkr: employer_create_params.Checkr | Omit = omit,
        demo: bool | Omit = omit,
        employee_consent: bool | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        onsite_clinic: bool | Omit = omit,
        website: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployerCreateResponse:
        """
        Create Employer

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/employers",
            body=await async_maybe_transform(
                {
                    "address": address,
                    "email": email,
                    "name": name,
                    "phones": phones,
                    "billing_address": billing_address,
                    "checkr": checkr,
                    "demo": demo,
                    "employee_consent": employee_consent,
                    "metadata": metadata,
                    "onsite_clinic": onsite_clinic,
                    "website": website,
                },
                employer_create_params.EmployerCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployerCreateResponse,
        )

    async def retrieve(
        self,
        employer_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployerRetrieveResponse:
        """
        Get Employer

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employer_id:
            raise ValueError(f"Expected a non-empty value for `employer_id` but received {employer_id!r}")
        return await self._get(
            f"/v1/employers/{employer_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployerRetrieveResponse,
        )

    async def list(
        self,
        *,
        login_token: str,
        user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployerListResponse:
        """
        Get Employers for Current User

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"login-token": login_token, "user-id": user_id, **(extra_headers or {})}
        return await self._get(
            "/v1/employers/list",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployerListResponse,
        )


class EmployersResourceWithRawResponse:
    def __init__(self, employers: EmployersResource) -> None:
        self._employers = employers

        self.create = to_raw_response_wrapper(
            employers.create,
        )
        self.retrieve = to_raw_response_wrapper(
            employers.retrieve,
        )
        self.list = to_raw_response_wrapper(
            employers.list,
        )

    @cached_property
    def service_bundles(self) -> ServiceBundlesResourceWithRawResponse:
        return ServiceBundlesResourceWithRawResponse(self._employers.service_bundles)


class AsyncEmployersResourceWithRawResponse:
    def __init__(self, employers: AsyncEmployersResource) -> None:
        self._employers = employers

        self.create = async_to_raw_response_wrapper(
            employers.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            employers.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            employers.list,
        )

    @cached_property
    def service_bundles(self) -> AsyncServiceBundlesResourceWithRawResponse:
        return AsyncServiceBundlesResourceWithRawResponse(self._employers.service_bundles)


class EmployersResourceWithStreamingResponse:
    def __init__(self, employers: EmployersResource) -> None:
        self._employers = employers

        self.create = to_streamed_response_wrapper(
            employers.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            employers.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            employers.list,
        )

    @cached_property
    def service_bundles(self) -> ServiceBundlesResourceWithStreamingResponse:
        return ServiceBundlesResourceWithStreamingResponse(self._employers.service_bundles)


class AsyncEmployersResourceWithStreamingResponse:
    def __init__(self, employers: AsyncEmployersResource) -> None:
        self._employers = employers

        self.create = async_to_streamed_response_wrapper(
            employers.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            employers.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            employers.list,
        )

    @cached_property
    def service_bundles(self) -> AsyncServiceBundlesResourceWithStreamingResponse:
        return AsyncServiceBundlesResourceWithStreamingResponse(self._employers.service_bundles)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["FaxListProvidersResponse", "Provider"]


class Provider(BaseModel):
    configured: bool
    """Whether the provider is properly configured"""

    is_default: bool = FieldInfo(alias="isDefault")
    """Whether this is the default provider"""

    name: str
    """Provider name"""


class FaxListProvidersResponse(BaseModel):
    providers: List[Provider]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from bluehive import BlueHive, AsyncBlueHive
from tests.utils import assert_matches_type
from bluehive.types import FaxSendResponse, FaxListProvidersResponse, FaxRetrieveStatusResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestFax:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list_providers(self, client: BlueHive) -> None:
        fax = client.fax.list_providers()
        assert_matches_type(FaxListProvidersResponse, fax, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list_providers(self, client: BlueHive) -> None:
        response = client.fax.with_raw_response.list_providers()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fax = response.parse()
        assert_matches_type(FaxListProvidersResponse, fax, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list_providers(self, client: BlueHive) -> None:
        with client.fax.with_streaming_response.list_providers() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fax = response.parse()
            assert_matches_type(FaxListProvidersResponse, fax, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_status(self, client: BlueHive) -> None:
        fax = client.fax.retrieve_status(
            "id",
        )
        assert_matches_type(FaxRetrieveStatusResponse, fax, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve_status(self, client: BlueHive) -> None:
        response = client.fax.with_raw_response.retrieve_status(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fax = response.parse()
        assert_matches_type(FaxRetrieveStatusResponse, fax, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_status(self, client: BlueHive) -> None:
        with client.fax.with_streaming_response.retrieve_status(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fax = response.parse()
            assert_matches_type(FaxRetrieveStatusResponse, fax, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve_status(self, client: BlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.fax.with_raw_response.retrieve_status(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_send(self, client: BlueHive) -> None:
        fax = client.fax.send(
            document={
                "content": "content",
                "content_type": "application/pdf",
            },
            to="to",
        )
        assert_matches_type(FaxSendResponse, fax, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_send_with_all_params(self, client: BlueHive) -> None:
        fax = client.fax.send(
            document={
                "content": "content",
                "content_type": "application/pdf",
                "filename": "filename",
            },
            to="to",
            from_="from",
            provider="provider",
            subject="subject",
        )
        assert_matches_type(FaxSendResponse, fax, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_send(self, client: BlueHive) -> None:
        response = client.fax.with_raw_response.send(
            document={
                "content": "content",
                "content_type": "application/pdf",
            },
            to="to",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fax = response.parse()
        assert_matches_type(FaxSendResponse, fax, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_send(self, client: BlueHive) -> None:
        with client.fax.with_streaming_response.send(
            document={
                "content": "content",
                "content_type": "application/pdf",
            },
            to="to",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fax = response.parse()
            assert_matches_type(FaxSendResponse, fax, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncFax:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list_providers(self, async_client: AsyncBlueHive) -> None:
        fax = await async_client.fax.list_providers()
        assert_matches_type(FaxListProvidersResponse, fax, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list_providers(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.fax.with_raw_response.list_providers()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fax = await response.parse()
        assert_matches_type(FaxListProvidersResponse, fax, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list_providers(self, async_client: AsyncBlueHive) -> None:
        async with async_client.fax.with_streaming_response.list_providers() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fax = await response.parse()
            assert_matches_type(FaxListProvidersResponse, fax, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_status(self, async_client: AsyncBlueHive) -> None:
        fax = await async_client.fax.retrieve_status(
            "id",
        )
        assert_matches_type(FaxRetrieveStatusResponse, fax, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_status(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.fax.with_raw_response.retrieve_status(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fax = await response.parse()
        assert_matches_type(FaxRetrieveStatusResponse, fax, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_status(self, async_client: AsyncBlueHive) -> None:
        async with async_client.fax.with_streaming_response.retrieve_status(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fax = await response.parse()
            assert_matches_type(FaxRetrieveStatusResponse, fax, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve_status(self, async_client: AsyncBlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.fax.with_raw_response.retrieve_status(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_send(self, async_client: AsyncBlueHive) -> None:
        fax = await async_client.fax.send(
            document={
                "content": "content",
                "content_type": "application/pdf",
            },
            to="to",
        )
        assert_matches_type(FaxSendResponse, fax, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_send_with_all_params(self, async_client: AsyncBlueHive) -> None:
        fax = await async_client.fax.send(
            document={
                "content": "content",
                "content_type": "application/pdf",
                "filename": "filename",
            },
            to="to",
            from_="from",
            provider="provider",
            subject="subject",
        )
        assert_matches_type(FaxSendResponse, fax, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_send(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.fax.with_raw_response.send(
            document={
                "content": "content",
                "content_type": "application/pdf",
            },
            to="to",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fax = await response.parse()
        assert_matches_type(FaxSendResponse, fax, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_send(self, async_client: AsyncBlueHive) -> None:
        async with async_client.fax.with_streaming_response.send(
            document={
                "content": "content",
                "content_type": "application/pdf",
            },
            to="to",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fax = await response.parse()
            assert_matches_type(FaxSendResponse, fax, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["EmployerCreateParams", "Address", "Phone", "Checkr"]


class EmployerCreateParams(TypedDict, total=False):
    address: Required[Address]

    email: Required[str]

    name: Required[str]

    phones: Required[Iterable[Phone]]

    billing_address: Annotated[Dict[str, object], PropertyInfo(alias="billingAddress")]

    checkr: Checkr

    demo: bool

    employee_consent: Annotated[bool, PropertyInfo(alias="employeeConsent")]

    metadata: Dict[str, object]

    onsite_clinic: Annotated[bool, PropertyInfo(alias="onsiteClinic")]

    website: str


class Address(TypedDict, total=False):
    city: Required[str]

    state: Required[str]

    street1: Required[str]

    zip_code: Required[Annotated[str, PropertyInfo(alias="zipCode")]]

    country: str

    street2: str


class Phone(TypedDict, total=False):
    number: Required[str]

    primary: bool

    type: str


class Checkr(TypedDict, total=False):
    id: Required[str]

    status: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["EmployeeUpdateResponse"]


class EmployeeUpdateResponse(BaseModel):
    """Employee updated successfully"""

    message: str

    success: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["VersionRetrieveResponse"]


class VersionRetrieveResponse(BaseModel):
    version: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["OrderRetrieveResultsResponse", "Meta", "Service"]


class Meta(BaseModel):
    order_id: str = FieldInfo(alias="orderId")

    page: float

    page_size: float = FieldInfo(alias="pageSize")

    returned: float

    total_services: float = FieldInfo(alias="totalServices")

    employee_id: Optional[str] = FieldInfo(alias="employeeId", default=None)

    order_number: Optional[str] = FieldInfo(alias="orderNumber", default=None)

    provider_id: Optional[str] = FieldInfo(alias="providerId", default=None)


class Service(BaseModel):
    service_id: str = FieldInfo(alias="serviceId")

    status: str

    alt_txt: Optional[str] = FieldInfo(alias="altTxt", default=None)

    completed_datetime: Optional[datetime] = None

    contacts: Optional[List[str]] = None

    drawn_datetime: Optional[datetime] = None

    file_ids: Optional[List[str]] = FieldInfo(alias="fileIds", default=None)

    message: Optional[str] = None

    result: Optional[str] = None

    results_posted: Optional[datetime] = FieldInfo(alias="resultsPosted", default=None)


class OrderRetrieveResultsResponse(BaseModel):
    meta: Meta

    services: List[Service]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

import httpx

from ..._types import Body, Omit, Query, Headers, NoneType, NotGiven, SequenceNotStr, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.employers import service_bundle_create_params, service_bundle_update_params
from ...types.employers.service_bundle_list_response import ServiceBundleListResponse
from ...types.employers.service_bundle_create_response import ServiceBundleCreateResponse
from ...types.employers.service_bundle_update_response import ServiceBundleUpdateResponse
from ...types.employers.service_bundle_retrieve_response import ServiceBundleRetrieveResponse

__all__ = ["ServiceBundlesResource", "AsyncServiceBundlesResource"]


class ServiceBundlesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ServiceBundlesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return ServiceBundlesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ServiceBundlesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return ServiceBundlesResourceWithStreamingResponse(self)

    def create(
        self,
        employer_id: str,
        *,
        bundle_name: str,
        service_ids: SequenceNotStr[str],
        _id: str | Omit = omit,
        limit: float | Omit = omit,
        occurrence: str | Omit = omit,
        recurring: bool | Omit = omit,
        roles: Optional[SequenceNotStr[str]] | Omit = omit,
        start_date: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServiceBundleCreateResponse:
        """
        Create Service Bundle

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employer_id:
            raise ValueError(f"Expected a non-empty value for `employer_id` but received {employer_id!r}")
        return self._post(
            f"/v1/employers/{employer_id}/service-bundles",
            body=maybe_transform(
                {
                    "bundle_name": bundle_name,
                    "service_ids": service_ids,
                    "_id": _id,
                    "limit": limit,
                    "occurrence": occurrence,
                    "recurring": recurring,
                    "roles": roles,
                    "start_date": start_date,
                },
                service_bundle_create_params.ServiceBundleCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ServiceBundleCreateResponse,
        )

    def retrieve(
        self,
        id: str,
        *,
        employer_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServiceBundleRetrieveResponse:
        """
        Get Service Bundle

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employer_id:
            raise ValueError(f"Expected a non-empty value for `employer_id` but received {employer_id!r}")
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/v1/employers/{employer_id}/service-bundles/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ServiceBundleRetrieveResponse,
        )

    def update(
        self,
        id: str,
        *,
        employer_id: str,
        bundle_name: str,
        service_ids: SequenceNotStr[str],
        _id: str | Omit = omit,
        limit: float | Omit = omit,
        occurrence: str | Omit = omit,
        recurring: bool | Omit = omit,
        roles: Optional[SequenceNotStr[str]] | Omit = omit,
        start_date: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServiceBundleUpdateResponse:
        """
        Update Service Bundle

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employer_id:
            raise ValueError(f"Expected a non-empty value for `employer_id` but received {employer_id!r}")
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._put(
            f"/v1/employers/{employer_id}/service-bundles/{id}",
            body=maybe_transform(
                {
                    "bundle_name": bundle_name,
                    "service_ids": service_ids,
                    "_id": _id,
                    "limit": limit,
                    "occurrence": occurrence,
                    "recurring": recurring,
                    "roles": roles,
                    "start_date": start_date,
                },
                service_bundle_update_params.ServiceBundleUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ServiceBundleUpdateResponse,
        )

    def list(
        self,
        employer_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServiceBundleListResponse:
        """
        List Service Bundles

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employer_id:
            raise ValueError(f"Expected a non-empty value for `employer_id` but received {employer_id!r}")
        return self._get(
            f"/v1/employers/{employer_id}/service-bundles",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ServiceBundleListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        employer_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete Service Bundle

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employer_id:
            raise ValueError(f"Expected a non-empty value for `employer_id` but received {employer_id!r}")
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/v1/employers/{employer_id}/service-bundles/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncServiceBundlesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncServiceBundlesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncServiceBundlesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncServiceBundlesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return AsyncServiceBundlesResourceWithStreamingResponse(self)

    async def create(
        self,
        employer_id: str,
        *,
        bundle_name: str,
        service_ids: SequenceNotStr[str],
        _id: str | Omit = omit,
        limit: float | Omit = omit,
        occurrence: str | Omit = omit,
        recurring: bool | Omit = omit,
        roles: Optional[SequenceNotStr[str]] | Omit = omit,
        start_date: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServiceBundleCreateResponse:
        """
        Create Service Bundle

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employer_id:
            raise ValueError(f"Expected a non-empty value for `employer_id` but received {employer_id!r}")
        return await self._post(
            f"/v1/employers/{employer_id}/service-bundles",
            body=await async_maybe_transform(
                {
                    "bundle_name": bundle_name,
                    "service_ids": service_ids,
                    "_id": _id,
                    "limit": limit,
                    "occurrence": occurrence,
                    "recurring": recurring,
                    "roles": roles,
                    "start_date": start_date,
                },
                service_bundle_create_params.ServiceBundleCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ServiceBundleCreateResponse,
        )

    async def retrieve(
        self,
        id: str,
        *,
        employer_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServiceBundleRetrieveResponse:
        """
        Get Service Bundle

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employer_id:
            raise ValueError(f"Expected a non-empty value for `employer_id` but received {employer_id!r}")
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/v1/employers/{employer_id}/service-bundles/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ServiceBundleRetrieveResponse,
        )

    async def update(
        self,
        id: str,
        *,
        employer_id: str,
        bundle_name: str,
        service_ids: SequenceNotStr[str],
        _id: str | Omit = omit,
        limit: float | Omit = omit,
        occurrence: str | Omit = omit,
        recurring: bool | Omit = omit,
        roles: Optional[SequenceNotStr[str]] | Omit = omit,
        start_date: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServiceBundleUpdateResponse:
        """
        Update Service Bundle

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employer_id:
            raise ValueError(f"Expected a non-empty value for `employer_id` but received {employer_id!r}")
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._put(
            f"/v1/employers/{employer_id}/service-bundles/{id}",
            body=await async_maybe_transform(
                {
                    "bundle_name": bundle_name,
                    "service_ids": service_ids,
                    "_id": _id,
                    "limit": limit,
                    "occurrence": occurrence,
                    "recurring": recurring,
                    "roles": roles,
                    "start_date": start_date,
                },
                service_bundle_update_params.ServiceBundleUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ServiceBundleUpdateResponse,
        )

    async def list(
        self,
        employer_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServiceBundleListResponse:
        """
        List Service Bundles

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employer_id:
            raise ValueError(f"Expected a non-empty value for `employer_id` but received {employer_id!r}")
        return await self._get(
            f"/v1/employers/{employer_id}/service-bundles",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ServiceBundleListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        employer_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete Service Bundle

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employer_id:
            raise ValueError(f"Expected a non-empty value for `employer_id` but received {employer_id!r}")
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/v1/employers/{employer_id}/service-bundles/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class ServiceBundlesResourceWithRawResponse:
    def __init__(self, service_bundles: ServiceBundlesResource) -> None:
        self._service_bundles = service_bundles

        self.create = to_raw_response_wrapper(
            service_bundles.create,
        )
        self.retrieve = to_raw_response_wrapper(
            service_bundles.retrieve,
        )
        self.update = to_raw_response_wrapper(
            service_bundles.update,
        )
        self.list = to_raw_response_wrapper(
            service_bundles.list,
        )
        self.delete = to_raw_response_wrapper(
            service_bundles.delete,
        )


class AsyncServiceBundlesResourceWithRawResponse:
    def __init__(self, service_bundles: AsyncServiceBundlesResource) -> None:
        self._service_bundles = service_bundles

        self.create = async_to_raw_response_wrapper(
            service_bundles.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            service_bundles.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            service_bundles.update,
        )
        self.list = async_to_raw_response_wrapper(
            service_bundles.list,
        )
        self.delete = async_to_raw_response_wrapper(
            service_bundles.delete,
        )


class ServiceBundlesResourceWithStreamingResponse:
    def __init__(self, service_bundles: ServiceBundlesResource) -> None:
        self._service_bundles = service_bundles

        self.create = to_streamed_response_wrapper(
            service_bundles.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            service_bundles.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            service_bundles.update,
        )
        self.list = to_streamed_response_wrapper(
            service_bundles.list,
        )
        self.delete = to_streamed_response_wrapper(
            service_bundles.delete,
        )


class AsyncServiceBundlesResourceWithStreamingResponse:
    def __init__(self, service_bundles: AsyncServiceBundlesResource) -> None:
        self._service_bundles = service_bundles

        self.create = async_to_streamed_response_wrapper(
            service_bundles.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            service_bundles.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            service_bundles.update,
        )
        self.list = async_to_streamed_response_wrapper(
            service_bundles.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            service_bundles.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = ["OrderUploadResultsParams", "File"]


class OrderUploadResultsParams(TypedDict, total=False):
    captcha_token: Required[Annotated[str, PropertyInfo(alias="captchaToken")]]

    order_access_code: Required[Annotated[str, PropertyInfo(alias="orderAccessCode")]]

    service_id: Required[Annotated[str, PropertyInfo(alias="serviceId")]]

    dob: str
    """Date of birth in YYYY-MM-DD format"""

    file_ids: Annotated[SequenceNotStr[str], PropertyInfo(alias="fileIds")]

    files: Iterable[File]

    last_name: Annotated[str, PropertyInfo(alias="lastName")]


class File(TypedDict, total=False):
    base64: Required[str]

    name: Required[str]

    type: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from bluehive import BlueHive, AsyncBlueHive
from tests.utils import assert_matches_type
from bluehive.types import (
    EmployerListResponse,
    EmployerCreateResponse,
    EmployerRetrieveResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestEmployers:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create(self, client: BlueHive) -> None:
        employer = client.employers.create(
            address={
                "city": "city",
                "state": "state",
                "street1": "street1",
                "zip_code": "zipCode",
            },
            email="dev@stainless.com",
            name="name",
            phones=[{"number": "number"}],
        )
        assert_matches_type(EmployerCreateResponse, employer, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: BlueHive) -> None:
        employer = client.employers.create(
            address={
                "city": "city",
                "state": "state",
                "street1": "street1",
                "zip_code": "zipCode",
                "country": "country",
                "street2": "street2",
            },
            email="dev@stainless.com",
            name="name",
            phones=[
                {
                    "number": "number",
                    "primary": True,
                    "type": "type",
                }
            ],
            billing_address={"foo": "bar"},
            checkr={
                "id": "id",
                "status": "status",
            },
            demo=True,
            employee_consent=True,
            metadata={"foo": "bar"},
            onsite_clinic=True,
            website="website",
        )
        assert_matches_type(EmployerCreateResponse, employer, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: BlueHive) -> None:
        response = client.employers.with_raw_response.create(
            address={
                "city": "city",
                "state": "state",
                "street1": "street1",
                "zip_code": "zipCode",
            },
            email="dev@stainless.com",
            name="name",
            phones=[{"number": "number"}],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employer = response.parse()
        assert_matches_type(EmployerCreateResponse, employer, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: BlueHive) -> None:
        with client.employers.with_streaming_response.create(
            address={
                "city": "city",
                "state": "state",
                "street1": "street1",
                "zip_code": "zipCode",
            },
            email="dev@stainless.com",
            name="name",
            phones=[{"number": "number"}],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employer = response.parse()
            assert_matches_type(EmployerCreateResponse, employer, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: BlueHive) -> None:
        employer = client.employers.retrieve(
            "employerId",
        )
        assert_matches_type(EmployerRetrieveResponse, employer, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: BlueHive) -> None:
        response = client.employers.with_raw_response.retrieve(
            "employerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employer = response.parse()
        assert_matches_type(EmployerRetrieveResponse, employer, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: BlueHive) -> None:
        with client.employers.with_streaming_response.retrieve(
            "employerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employer = response.parse()
            assert_matches_type(EmployerRetrieveResponse, employer, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: BlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employer_id` but received ''"):
            client.employers.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list(self, client: BlueHive) -> None:
        employer = client.employers.list(
            login_token="login-token",
            user_id="user-id",
        )
        assert_matches_type(EmployerListResponse, employer, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: BlueHive) -> None:
        response = client.employers.with_raw_response.list(
            login_token="login-token",
            user_id="user-id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employer = response.parse()
        assert_matches_type(EmployerListResponse, employer, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: BlueHive) -> None:
        with client.employers.with_streaming_response.list(
            login_token="login-token",
            user_id="user-id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employer = response.parse()
            assert_matches_type(EmployerListResponse, employer, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncEmployers:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncBlueHive) -> None:
        employer = await async_client.employers.create(
            address={
                "city": "city",
                "state": "state",
                "street1": "street1",
                "zip_code": "zipCode",
            },
            email="dev@stainless.com",
            name="name",
            phones=[{"number": "number"}],
        )
        assert_matches_type(EmployerCreateResponse, employer, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncBlueHive) -> None:
        employer = await async_client.employers.create(
            address={
                "city": "city",
                "state": "state",
                "street1": "street1",
                "zip_code": "zipCode",
                "country": "country",
                "street2": "street2",
            },
            email="dev@stainless.com",
            name="name",
            phones=[
                {
                    "number": "number",
                    "primary": True,
                    "type": "type",
                }
            ],
            billing_address={"foo": "bar"},
            checkr={
                "id": "id",
                "status": "status",
            },
            demo=True,
            employee_consent=True,
            metadata={"foo": "bar"},
            onsite_clinic=True,
            website="website",
        )
        assert_matches_type(EmployerCreateResponse, employer, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.employers.with_raw_response.create(
            address={
                "city": "city",
                "state": "state",
                "street1": "street1",
                "zip_code": "zipCode",
            },
            email="dev@stainless.com",
            name="name",
            phones=[{"number": "number"}],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employer = await response.parse()
        assert_matches_type(EmployerCreateResponse, employer, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncBlueHive) -> None:
        async with async_client.employers.with_streaming_response.create(
            address={
                "city": "city",
                "state": "state",
                "street1": "street1",
                "zip_code": "zipCode",
            },
            email="dev@stainless.com",
            name="name",
            phones=[{"number": "number"}],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employer = await response.parse()
            assert_matches_type(EmployerCreateResponse, employer, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncBlueHive) -> None:
        employer = await async_client.employers.retrieve(
            "employerId",
        )
        assert_matches_type(EmployerRetrieveResponse, employer, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.employers.with_raw_response.retrieve(
            "employerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employer = await response.parse()
        assert_matches_type(EmployerRetrieveResponse, employer, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncBlueHive) -> None:
        async with async_client.employers.with_streaming_response.retrieve(
            "employerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employer = await response.parse()
            assert_matches_type(EmployerRetrieveResponse, employer, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncBlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employer_id` but received ''"):
            await async_client.employers.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncBlueHive) -> None:
        employer = await async_client.employers.list(
            login_token="login-token",
            user_id="user-id",
        )
        assert_matches_type(EmployerListResponse, employer, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.employers.with_raw_response.list(
            login_token="login-token",
            user_id="user-id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employer = await response.parse()
        assert_matches_type(EmployerListResponse, employer, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncBlueHive) -> None:
        async with async_client.employers.with_streaming_response.list(
            login_token="login-token",
            user_id="user-id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employer = await response.parse()
            assert_matches_type(EmployerListResponse, employer, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["FaxRetrieveStatusResponse"]


class FaxRetrieveStatusResponse(BaseModel):
    id: str
    """Fax identifier"""

    created_at: str = FieldInfo(alias="createdAt")
    """ISO timestamp when fax was created"""

    from_: str = FieldInfo(alias="from")
    """Sender fax number"""

    provider: str
    """Provider used to send the fax"""

    status: Literal["queued", "dialing", "sending", "delivered", "failed", "cancelled", "retrying"]
    """Current fax status"""

    to: str
    """Recipient fax number"""

    updated_at: str = FieldInfo(alias="updatedAt")
    """ISO timestamp when status was last updated"""

    cost: Optional[float] = None
    """Cost of the fax"""

    delivered_at: Optional[str] = FieldInfo(alias="deliveredAt", default=None)
    """ISO timestamp when fax was delivered"""

    duration: Optional[float] = None
    """Call duration in seconds"""

    error_message: Optional[str] = FieldInfo(alias="errorMessage", default=None)
    """Error message if fax failed"""

    page_count: Optional[float] = FieldInfo(alias="pageCount", default=None)
    """Number of pages in the fax"""

    provider_data: Optional[Dict[str, object]] = FieldInfo(alias="providerData", default=None)
    """Provider-specific additional data"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["OrderUpdateResponse"]


class OrderUpdateResponse(BaseModel):
    message: str

    order_id: str = FieldInfo(alias="orderId")

    order_number: str = FieldInfo(alias="orderNumber")

    success: Literal[True]

    updated_fields: Optional[List[str]] = FieldInfo(alias="updatedFields", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "OrderSendForEmployeeResponse",
    "UnionMember0",
    "UnionMember0UnavailableService",
    "UnionMember1",
    "UnionMember1OrderResult",
    "UnionMember1UnavailableService",
]


class UnionMember0UnavailableService(BaseModel):
    reason: str
    """Why the service was unavailable"""

    service_id: str = FieldInfo(alias="serviceId")

    service_name: Optional[str] = FieldInfo(alias="serviceName", default=None)


class UnionMember0(BaseModel):
    order_id: str = FieldInfo(alias="orderId")

    order_number: str = FieldInfo(alias="orderNumber")

    success: Literal[True]

    message: Optional[str] = None

    partial_success: Optional[bool] = FieldInfo(alias="partialSuccess", default=None)
    """True when some services were unavailable but order was still created"""

    unavailable_services: Optional[List[UnionMember0UnavailableService]] = FieldInfo(
        alias="unavailableServices", default=None
    )
    """Services that could not be included in the order"""


class UnionMember1OrderResult(BaseModel):
    order_id: str = FieldInfo(alias="orderId")

    order_number: str = FieldInfo(alias="orderNumber")

    provider_id: str = FieldInfo(alias="providerId")


class UnionMember1UnavailableService(BaseModel):
    reason: str
    """Why the service was unavailable"""

    service_id: str = FieldInfo(alias="serviceId")

    service_name: Optional[str] = FieldInfo(alias="serviceName", default=None)


class UnionMember1(BaseModel):
    order_results: List[UnionMember1OrderResult] = FieldInfo(alias="orderResults")

    status: Literal["split"]

    success: Literal[True]

    message: Optional[str] = None

    partial_success: Optional[bool] = FieldInfo(alias="partialSuccess", default=None)
    """True when some services were unavailable but orders were still created"""

    unavailable_services: Optional[List[UnionMember1UnavailableService]] = FieldInfo(
        alias="unavailableServices", default=None
    )
    """Services that could not be included in any order"""


OrderSendForEmployeeResponse: TypeAlias = Union[UnionMember0, UnionMember1]
